@@ -2,6 +2,7 @@ import fugashi
 import jaconv
 import re
 import pathlib
+import sys
 
 from .mapping import *
 
@@ -14,6 +15,43 @@ SYSTEMS = {
         'nihon': NIHONSHIKI,
 }
 
+if sys.version_info >= (3, 7):
+    def is_ascii(s):
+        return s.isascii()
+else:
+    def is_ascii(s):
+        for c in s: 
+            if c > '\x7f': 
+                return False 
+        return True 
+
+def has_foreign_lemma(word):
+    """Check if a word has a foreign lemma.
+
+    This doesn't get its own field, the lemma field is overloaded. There are
+    also cases where the lemma field is overloaded with non-foreign-lemma
+    information."""
+
+    if '-' in word.surface: 
+        # TODO check if this is actually possible in vanilla unidic
+        return False
+
+    if not word.feature.lemma:
+        # No lemma means no foreign lemma
+        return False
+
+    lemma = word.feature.lemma
+
+    if not '-' in lemma:
+        return False
+
+    cand = lemma.split('-')[-1]
+    # NOTE: some words have 外国 instead of a foreign spelling. ジル
+    # (Jill?) is an example. Unclear why this is the case.
+    # NOTE: There are other hyphenated lemmas, like 私-代名詞. 
+    if is_ascii(cand):
+        return True
+
 def load_exceptions():
     cdir = pathlib.Path(__file__).parent.absolute()
     exceptions = {}
@@ -40,9 +78,9 @@ class Cutlet:
         self.tagger = fugashi.Tagger()
         self.exceptions = load_exceptions()
 
-        self.use_tch = (self.system in ('hepburn'))
+        self.use_tch = (self.system in ('hepburn',))
         self.use_wa  = (self.system in ('hepburn', 'kunrei'))
-        self.use_he  = (self.system in ('nihon'))
+        self.use_he  = (self.system in ('nihon',))
         self.use_wo  = (self.system in ('hepburn', 'nihon'))
 
         self.use_foreign_spelling = True
@@ -69,6 +107,8 @@ class Cutlet:
         capitalized. This is typically the desired behavior if the input is a
         complete sentence.
         """
+        if not text:
+            return ''
 
         words = self.tagger.parseToNodeList(text)
 
@@ -128,7 +168,7 @@ class Cutlet:
         if word.surface.isdigit():
             return word.surface
 
-        if word.surface.isascii():
+        if is_ascii(word.surface):
             return word.surface
 
         if word.feature.pos1 == '補助記号':
@@ -143,13 +183,8 @@ class Cutlet:
                 word.feature.pos1 == '助詞' and word.feature.pron == 'オ'):
             return 'o'
         elif (self.use_foreign_spelling and 
-                '-' not in word.surface and word.feature.lemma and
-                '-' in word.feature.lemma and
-                '外国' not in word.feature.lemma):
+                has_foreign_lemma(word)):
             # this is a foreign word with known spelling
-
-            #NOTE: some words have 外国 instead of a foreign spelling. ジル
-            # (Jill?) is an example. Unclear why this is the case.
             return word.feature.lemma.split('-')[-1]
         elif word.feature.kana:
             # for known words
